@@ -517,10 +517,14 @@ create_global_store (ETableConfig *config)
 
 	global_store = e_table_memory_store_new (store_columns);
 	for (i = 0; config->source_spec->columns[i]; i++) {
-		char *text = g_strdup (dgettext (config->domain,
-								  config->source_spec->columns[i]->title));
 
-		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), i, NULL, text);
+		char *text;
+
+		if (config->source_spec->columns[i]->disabled)
+			continue;
+
+		text = g_strdup (dgettext (config->domain, config->source_spec->columns[i]->title));
+		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), -1, NULL, text);
 	}
 }
 
